#[non_exhaustive]pub struct Output {
pub width: usize,
pub height: usize,
pub cells: Vec<Cell>,
pub cursor: Cursor,
pub title: String,
pub mode: ScreenMode,
}Expand description
The parent type for all output
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.width: usizeThe shadow terminal’s width.
height: usizeThe shadow terminal’s height.
cells: Vec<Cell>A 1D array of all the cells in the shadow terminal’s screen.
cursor: CursorThe shadow terminal’s cursor state.
title: StringThe title of the terminal.
mode: ScreenModeWhether the terminal is in the primary (scrolling) mode or the alternate mode.
Implementations
Sourceimpl Output
impl Output
Sourcepub fn convert_to_foreign(
native: CompleteSurface,
) -> Result<Self, ShadowTerminalError>
pub fn convert_to_foreign( native: CompleteSurface, ) -> Result<Self, ShadowTerminalError>
Convert native output to a structure more suitable for non-Rust users.
Errors
If trying to convert the scrollback.