Enum CompleteSurface

#[non_exhaustive]
pub enum CompleteSurface { Scrollback(CompleteScrollback), Screen(CompleteScreen), }
A complete, cell-for-cell duplicate of the current Wezterm shadow terminal.

When diffing is deemed ineffeicient, say when resizing, or when scrolling in vim, it’s hopefully more efficient to just send the entire view of the terminal. After all, diffs have to be applied one by one, so there must come a point where it’s cheaper to just send all the cell data verbatim.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Scrollback(CompleteScrollback)

A complete scrollback.



Screen(CompleteScreen)

The current view of the terminal, regardless of whether it’s the primary or alternate screen.