#[non_exhaustive]pub enum SurfaceDiff {
Scrollback(ScrollbackDiff),
Screen(ScreenDiff),
}Expand description
Hopefully the most common form of output, therefore a small diff of changes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Scrollback(ScrollbackDiff)
Output generated by the terminal whilst in REPL mode, aka, the “primary screen”.
Screen(ScreenDiff)
The current view of the terminal, regardless of whether it’s the primary or alternate screen.