#[non_exhaustive]pub struct CompleteScrollback {
pub surface: Surface,
pub position: usize,
}Expand description
Every cell in the current scrollback, and the current location if the scrollback is actively being scrolled.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.surface: SurfaceThe termwiz surface data.
position: usizeThe position of the current scroll, so it would be 0, if the user is not scrolling.