#[non_exhaustive]pub struct ScrollbackDiff {
pub changes: Vec<Change>,
pub size: (usize, usize),
pub position: usize,
pub height: usize,
}Expand description
The scrollback is a history, albeit limited, of all the output whilst in REPL mode, aka the “primary screen”.
Even though it’s called the “scrollback”, it’s still the main interactive view, we just mostly are seeing the bottom of the scrollback where the current prompt is.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.changes: Vec<Change>A list of termwiz changes that, once applied, should bring any surfaces following this
view, up to date.
size: (usize, usize)The size of the underlying PTY at the time this diff was made.
position: usizeThe current position of the user’s view on the scrollback. Is 0 when not scrolling.
height: usizeThe size of the current scrollback. Can increase up to the configured maximum.